@@ -37,4 +37,6 @@ RHYTHMS = ("c4", "c8 c8", "c16 c16 c16 c16", "c8 c16 c16",
            "c16 c16 c16 c16 c8", #33
            "c16 c16 c16 c16 c16 c16", #34
 )
+solmisation_syllables = ["SO,","SI,","LU,","LA,","LI,","TU,","TI,","DO","DI","RU","RE","RI","MU","MI","FA","FI","SU","SO","SI","LU","LA","LI","TU","TI","DO'","DI'","RU'","RE'","RI'","MU'","MI'","FA'","FI'","SU'","SO'"]
 
+solmisation_notenames = ["g","gis","aes","a","ais","bes","b","c'","cis'","des'","d'","dis'","ees'","e'", "f'","fis'","ges'","g'","gis'","aes'","a'","ais'","bes'","b'","c''","cis''","des''","d''","dis''","ees''","e''", "f''","fis''","ges''","g''"]
