@@ -65,8 +65,7 @@ class Teacher(abstract.Teacher):
         self.m_is_first_question = self.q_status == self.QSTATUS_NO
 
         v = []
-        for n in ['c', 'cis', 'd', 'dis', 'e', 'f', 'fis',
-                  'g', 'gis', 'a', 'ais', 'b']:
+        for n in mpd.MusicalPitch.notenames:
             v.extend([n] * self.get_int(n+"_weight"))
         if not v:
             return self.ERR_CONFIG
@@ -82,16 +81,14 @@ class Teacher(abstract.Teacher):
         return self.OK
     def guess_answer(self, notename):
         if notename == self.m_question:
-            if self.q_status == self.QSTATUS_NEW \
-                    and not self.m_custom_mode:
+            if self.q_status == self.QSTATUS_NEW:
                 self.m_statistics.add_correct(notename)
             self.maybe_auto_new_question()
             self.q_status = self.QSTATUS_SOLVED
             return 1
         else:
             if self.q_status == self.QSTATUS_NEW:
-                if not self.m_custom_mode:
-                    self.m_statistics.add_wrong(self.m_question, notename)
+                self.m_statistics.add_wrong(self.m_question, notename)
                 self.q_status = self.QSTATUS_WRONG
     def play_question(self):
         if self.q_status == self.QSTATUS_NO:
@@ -99,8 +96,6 @@ class Teacher(abstract.Teacher):
         utils.play_note(4,
             mpd.notename_to_int(self.m_question) + self.m_octave * 12)
     def give_up(self):
-        if not self.m_custom_mode:
-            self.m_statistics.reset_session()
         self.q_status = self.QSTATUS_GIVE_UP
     def spank_me_play_question(self):
         t1 = utils.new_percussion_track()
@@ -124,8 +119,7 @@ class Gui(abstract.Gui):
         def update_accels(*ignore):
             self.g_piano.m_keys = self.get_accel_key_list()
             self.g_piano.queue_draw()
-        for notename in ('c', 'cis', 'd', 'dis', 'e', 'f', 'fis',
-                'g', 'gis', 'a', 'ais', 'b'):
+        for notename in mpd.MusicalPitch.notenames:
             self.add_watch('tone_%s_ak' % notename, update_accels)
         self.practise_box.pack_start(self.g_piano)
 
@@ -143,8 +137,6 @@ class Gui(abstract.Gui):
         # config_box #
         ##############
         self.config_box.set_spacing(gu.PAD_SMALL)
-        # bad variable name, but this is the config options that should
-        # not change without chaning lesson_id
         self.g_config_elems = gu.bVBox(self.config_box, False)
         table = gtk.Table()
         table.set_border_width(gu.PAD_SMALL)
@@ -200,8 +192,7 @@ class Gui(abstract.Gui):
                                    _("Identify tone"))
     def get_accel_key_list(self):
         v = []
-        for k in ('c', 'cis', 'd', 'dis', 'e', 'f', 'fis',
-                  'g', 'gis', 'a', 'ais', 'b'):
+        for k in mpd.MusicalPitch.notenames:
             self.m_key_bindings['tone_%s_ak' % k] \
                 = lambda self=self, k=k: self.on_answer_from_user(k)
             v.append(self.get_string('tone_%s_ak' % k))
@@ -280,28 +271,46 @@ _("""You have to select some tones practise. Do this on the config page by setti
             _("Correct, but you have already solved this question"),
             _("Wrong, but you have already solved this question"),
         ])
-        if 'white_keys_weight' in self.m_t.m_P.header:
-            if type(self.m_t.m_P.header.white_keys_weight) == list \
-                    and len(self.m_t.m_P.header.white_keys_weight) == 7:
-                for idx, n in enumerate(('c', 'd', 'e', 'f', 'g', 'a', 'b')):
-                    self.set_float('%s_weight' % n, self.m_t.m_P.header.white_keys_weight[idx])
-            else:
-                gu.dialog_ok("The white_keys_weight variable in the lesson file '%s' had wrong type" % os.path.abspath(self.m_t.m_P.m_filename), msgtype=gtk.MESSAGE_WARNING)
+        if self.m_t.m_custom_mode:
+            for notename, value in zip(mpd.MusicalPitch.notenames,
+                                       self.get_list('custom_mode_cfg')):
+                try:
+                    value = float(value)
+                except ValueError:
+                    value = 0.0
+                self.set_float('%s_weight' % notename, value)
         else:
-            for idx, n in enumerate(('c', 'd', 'e', 'f', 'g', 'a', 'b')):
-                self.set_float('%s_weight' % n, 0.0)
-        if 'black_keys_weight' in self.m_t.m_P.header:
-            if type(self.m_t.m_P.header.black_keys_weight) == list \
-                    and len(self.m_t.m_P.header.black_keys_weight) == 5:
+            if 'white_keys_weight' in self.m_t.m_P.header:
+                if type(self.m_t.m_P.header.white_keys_weight) == list \
+                        and len(self.m_t.m_P.header.white_keys_weight) == 7:
+                    for idx, n in enumerate(mpd.MusicalPitch.natural_notenames):
+                        try:
+                            weight = float(self.m_t.m_P.header.white_keys_weight[idx])
+                        except ValueError:
+                            weight = 0.0
+                        self.set_float('%s_weight' % n, weight)
+                else:
+                    gu.dialog_ok("The white_keys_weight variable in the lesson file '%s' had wrong type" % os.path.abspath(self.m_t.m_P.m_filename), msgtype=gtk.MESSAGE_WARNING)
+            else:
+                for idx, n in enumerate(mpd.MusicalPitch.notenames):
+                    self.set_float('%s_weight' % n, 0.0)
+            if 'black_keys_weight' in self.m_t.m_P.header:
+                if type(self.m_t.m_P.header.black_keys_weight) == list \
+                        and len(self.m_t.m_P.header.black_keys_weight) == 5:
+                    for idx, n in enumerate(mpd.MusicalPitch.sharp_notenames):
+                        try:
+                            weight = float(self.m_t.m_P.header.black_keys_weight[idx])
+                        except ValueError:
+                            weight = 0.0
+                        self.set_float('%s_weight' % n, weight)
+                else:
+                    gu.dialog_ok("The black_keys_weight variable in the lesson file '%s' had wrong type" % os.path.abspath(self.m_t.m_P.m_filename), msgtype=gtk.MESSAGE_WARNING)
+            else:
                 for idx, n in enumerate(('cis', 'dis', 'fis', 'gis', 'ais')):
-                    self.set_float('%s_weight' % n, self.m_t.m_P.header.black_keys_weight[idx])
-            else:
-                gu.dialog_ok("The black_keys_weight variable in the lesson file '%s' had wrong type" % os.path.abspath(self.m_t.m_P.m_filename), msgtype=gtk.MESSAGE_WARNING)
-        else:
-            for idx, n in enumerate(('cis', 'dis', 'fis', 'gis', 'ais')):
-                self.set_float('%s_weight' % n, 0.0)
+                    self.set_float('%s_weight' % n, 0.0)
         if self.m_t.m_custom_mode:
             self.g_config_elems.show()
+            self.m_t.m_statistics.reset_custom_mode_session(self.m_t.m_P.m_filename)
         else:
             self.g_config_elems.hide()
             self.m_t.m_statistics.reset_session()
@@ -312,6 +321,9 @@ _("""You have to select some tones practise. Do this on the config page by setti
         self.std_buttons_start_practise()
         self.m_t.q_status = self.QSTATUS_NO
     def on_end_practise(self):
+        if self.m_t.m_custom_mode:
+            self.set_list('custom_mode_cfg', [self.get_float('%s_weight' % x)
+                         for x in mpd.MusicalPitch.notenames])
         self.m_t.end_practise()
         self.std_buttons_end_practise()
 
