@@ -1,14 +1,18 @@
 # Solfege - free ear training software
-# Copyright (C) 2007, 2008 Tom Cato Amundsen
+# Copyright (C) 2007, 2008, 2011 Tom Cato Amundsen
 # License is GPL, see file COPYING
 
 import unittest
 from solfege import mpd
+from solfege.testlib import TmpFileBase
 from solfege.mpd.track import Track, MidiEventStream
 from solfege.mpd.rat import Rat
 from solfege import lessonfile
 from solfege import cfg
 
+class TmpFile(TmpFileBase):
+    parserclass = lessonfile.QuestionsLessonfile
+
 class TestTrack(unittest.TestCase):
     def test_simple1(self):
         t = Track()
@@ -48,8 +52,9 @@ class TestTrack(unittest.TestCase):
         self.assertEquals("p0:0 p1:0 v0:100 n0:92 n0:90 d1/8 o92 v1:100 n1:90 d1/8 o90 n0:92 d1/8 o92 n0:94 d1/8 o94 o90", m.str_repr(1))
 
 
-class TestMidiEventStream(unittest.TestCase):
+class TestMidiEventStream(TmpFile):
     def setUp(self):
+        TmpFile.setUp(self)
         cfg.set_bool('config/override_default_instrument', True)
     def test_track1(self):
         t = Track()
@@ -110,8 +115,7 @@ class TestMidiEventStream(unittest.TestCase):
         self.assertEquals(MidiEventStream(t1, t2, t3).str_repr(details=1),
             "p0:3 p1:4 p2:5 v0:88 n0:93 v1:100 n1:94 v2:100 n2:95 d1/4 o93 o94 o95")
     def test_track2(self):
-        self.p = lessonfile.QuestionsLessonfile()
-        self.p.parse_string("""
+        self.do_file("""
         header { random_transpose = no }
         question { music = music("\staff{ c'' }"
                                 + "\\addvoice{ e' }"
@@ -121,8 +125,7 @@ class TestMidiEventStream(unittest.TestCase):
         self.p._idx = 0
         tracklist = mpd.music_to_tracklist(self.p.get_question()['music'].get_mpd_music_string(self.p))
     def test_track3(self):
-        self.p = lessonfile.QuestionsLessonfile()
-        self.p.parse_string("""
+        self.do_file("""
         header { random_transpose = no }
         question { music = music("\staff{ c''1 c''1 }"
                                 + "\\addvoice{ r4 e'2. e'1 }"
@@ -152,8 +155,7 @@ class TestMidiEventStream(unittest.TestCase):
           "n0:72 n1:64 n2:55 n3:48 d1/1 "
           "o72 o64 o55 o48")
     def test_track3_1(self):
-        self.p = lessonfile.QuestionsLessonfile()
-        self.p.parse_string("""
+        self.do_file("""
         header { random_transpose = no }
         question { music = music("\staff{ c''1 c''1 }"
                                 + "\staff{ r4 r g2 g1 }")
@@ -173,8 +175,7 @@ class TestMidiEventStream(unittest.TestCase):
         self.assertEquals(MidiEventStream(*tracklist).str_repr(details=1),
           "p0:1 p1:2 v0:100 n0:72 d1/2 v1:100 n1:55 d1/2 o72 o55 n0:72 n1:55 d1/1 o72 o55")
     def test_track3_2(self):
-        self.p = lessonfile.QuestionsLessonfile()
-        self.p.parse_string(r"""
+        self.do_file(r"""
         header { random_transpose = no }
         question { music = music("\staff{ c''1 c''1 }"
                                 + "\staff{ r4 r g2 g1 }"
