@@ -4,19 +4,21 @@ import pygtk
 pygtk.require("2.0")
 import sys, os
 sys.path.append(".")
-import src.i18n
-src.i18n.setup(".")
-import src.cfg
-import src
-from src import filesystem
-src.cfg.initialise("default.config", None, filesystem.rcfile())
+import solfege.i18n
+solfege.i18n.setup(".")
+import solfege.cfg
+from solfege import filesystem
+solfege.cfg.initialise("default.config", None, filesystem.rcfile())
 
 
 
-import gnome.ui
-import mpd, mpd.musicdisplayer, soundcard
 import gtk
-from src import gu
+
+from solfege import gu
+from solfege import mpd
+from solfege.mpd.musicdisplayer import MusicDisplayer
+from solfege import soundcard
+from solfege import utils
 
 musicfile = "mpd-test.txt"
 
@@ -42,14 +44,13 @@ class DisplaytestWindow(gtk.Window):
         self.m_buf = self.g_text.get_buffer()
         self.m_buf.insert(self.m_buf.get_end_iter(), s)
         vbox.pack_start(self.g_text)
-        self.g_displayer = mpd.musicdisplayer.MusicDisplayer()
+        self.g_displayer = MusicDisplayer()
         self.g_displayer.set_size_request(200, 200)
         self.g_displayer.show()
         self.vbox.pack_start(self.g_displayer)
         gu.bButton(vbox, "Parse", self.on_parse)
         gu.bButton(vbox, "Display", self.on_display)
         gu.bButton(vbox, "Display first notes", self.on_display_first_notes)
-        #gu.bButton(vbox, "Display last notes", self.on_display_last_notes)
         gu.bButton(vbox, "Play", self.on_play)
         gu.bButton(vbox, "Play first", self.on_play_first)
     def save(self, text):
@@ -69,17 +70,12 @@ class DisplaytestWindow(gtk.Window):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
         self.save(t)
-        self.g_displayer.display(t, 20, mpd.FIRST)
-    def on_display_last_notes(self, _o):
-        t = self.m_buf.get_text(self.m_buf.get_start_iter(),
-                                self.m_buf.get_end_iter(), True)
-        self.save(t)
-        self.g_displayer.display(t, 20, mpd.LAST)
+        self.g_displayer.display(t, 20, mpd.Rat(0, 1))
     def on_play(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
         self.save(t)
-        mpd.play_music(t, (120, 4), 0, 100)
+        utils.play_music(t, (120, 4), 0, 100)
     def on_play_first(self, _o):
         t = self.m_buf.get_text(self.m_buf.get_start_iter(),
                                 self.m_buf.get_end_iter(), True)
@@ -90,7 +86,7 @@ class DisplaytestWindow(gtk.Window):
 #soundcard.initialise_devicefile("/dev/sequencer", 0)
 #soundcard.initialise_devicefile("/dev/music", 0)
 #soundcard.initialise_using_fake_synth()
-soundcard.initialise_external_midiplayer("/usr/bin/timidity %s")
+soundcard.initialise_external_midiplayer()
 
 w = DisplaytestWindow()
 w.connect('destroy', gtk.main_quit)
